@@ -3,7 +3,7 @@ package Text::Xslate::PP;
 use 5.008_001;
 use strict;
 
-our $VERSION = '0.2013';
+our $VERSION = '0.2014';
 $VERSION =~ s/_//; # for developpers versions
 
 BEGIN{
@@ -629,7 +629,7 @@ Text::Xslate::PP - Yet another Text::Xslate runtime in pure Perl
 
 =head1 VERSION
 
-This document describes Text::Xslate::PP version 0.2013.
+This document describes Text::Xslate::PP version 0.2014.
 
 =head1 DESCRIPTION
 
@@ -651,7 +651,7 @@ XS/PP mode might be switched with C<< $ENV{XSLATE} = 'pp' or 'xs' >>.
 From 0.1024 on, there are two pure Perl engines.
 C<Text::Xslate::PP::Booster>, enabled by C<< $ENV{XSLATE} = 'pp=booster' >>,
 generates optimized Perl code from intermediate code.
-C<Text::Xlsate::PP::Opcode>, enabled by C<< $ENV{XSLATE} = 'pp=opcode' >>,
+C<Text::Xslate::PP::Opcode>, enabled by C<< $ENV{XSLATE} = 'pp=opcode' >>,
 executes intermediate code directly, emulating the virtual machine in pure Perl.
 
 PP::Booster is much faster than PP::Opcode, but it may be less stable.
